<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="190"/>
        <source>Acknowledgements</source>
        <translation>Remerciements </translation>
    </message>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1238"/>
        <source>Version: %1</source>
        <translation>Version : %1</translation>
    </message>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1242"/>
        <source>%1 is released under %2</source>
        <translation>%1 est publié sous %2</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="900"/>
        <source>Black</source>
        <translation>Noir</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="903"/>
        <source>White</source>
        <translation>Blanc</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="906"/>
        <source>Dark Gray</source>
        <translation>Gris foncé</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="909"/>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="912"/>
        <source>Light Gray</source>
        <translation>Gris clair</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="915"/>
        <source>Red</source>
        <translation>Rouge</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="918"/>
        <source>Green</source>
        <translation>Vert</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="921"/>
        <source>Blue</source>
        <translation>Bleu</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="924"/>
        <source>Cyan</source>
        <translation>Cyan</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="927"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="930"/>
        <source>Yellow</source>
        <translation>Jaune</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="933"/>
        <source>Dark Red</source>
        <translation>Rouge foncé</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="936"/>
        <source>Dark Green</source>
        <translation>Vert foncé</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="939"/>
        <source>Dark Blue</source>
        <translation>Bleu foncé</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="942"/>
        <source>Dark Cyan</source>
        <translation>Cyan foncé</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="945"/>
        <source>Dark Magenta</source>
        <translation>Magenta foncé</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="948"/>
        <source>Dark Yellow</source>
        <translation>Jaune foncé</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="43"/>
        <source>Confirm</source>
        <translation>Confirmer</translation>
    </message>
</context>
<context>
    <name>DKeySequenceEdit</name>
    <message>
        <location filename="../widgets/dkeysequenceedit.cpp" line="85"/>
        <source>Enter a new shortcut</source>
        <translation>Entrer un nouveau raccourci</translation>
    </message>
</context>
<context>
    <name>DLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="471"/>
        <source>Stop reading</source>
        <translation>Arrêter la lecture</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="473"/>
        <source>Text to Speech</source>
        <translation>Texte vers voix</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="496"/>
        <source>Translate</source>
        <translation>Traduire</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="518"/>
        <source>Speech To Text</source>
        <translation>Voix vers texte</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewDialogPrivate</name>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="232"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1175"/>
        <source>Advanced</source>
        <translation>Avancés</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="255"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="256"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1596"/>
        <source>Print</source>
        <comment>button</comment>
        <translation>Impression</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="272"/>
        <source>Basic</source>
        <translation>De base</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="287"/>
        <source>Printer</source>
        <translation>Imprimante</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="301"/>
        <source>Copies</source>
        <translation>Copies</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="321"/>
        <source>Page range</source>
        <translation>Intervalle de pages</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="323"/>
        <source>All</source>
        <translation>Tout</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="324"/>
        <source>Current page</source>
        <translation>Page actuelle</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="325"/>
        <source>Select pages</source>
        <translation>Sélectionner les pages</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="340"/>
        <source>Orientation</source>
        <translation>Orientation</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="364"/>
        <source>Portrait</source>
        <translation>Portrait</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="374"/>
        <source>Landscape</source>
        <translation>Paysage</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="402"/>
        <source>Pages</source>
        <translation>Pages</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="412"/>
        <source>Color mode</source>
        <translation>Mode de couleur</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="414"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1553"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1620"/>
        <source>Color</source>
        <translation>Couleur</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="414"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1605"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1620"/>
        <source>Grayscale</source>
        <translation>Niveaux de gris</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="425"/>
        <source>Margins</source>
        <translation>Marges</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
        <source>Narrow (mm)</source>
        <translation>Étroit (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
        <source>Normal (mm)</source>
        <translation>Normale (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
        <source>Moderate (mm)</source>
        <translation>Modéré (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
        <source>Customize (mm)</source>
        <translation>Personnaliser (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="433"/>
        <source>Top</source>
        <translation>Haut</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="436"/>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="439"/>
        <source>Bottom</source>
        <translation>Bas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="442"/>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="487"/>
        <source>Scaling</source>
        <translation>Mise à l&apos;échelle</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="501"/>
        <source>Actual size</source>
        <translation>Taille actuelle</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="510"/>
        <source>Scale</source>
        <translation>Échelle</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="541"/>
        <source>Paper</source>
        <translation>Papier</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="551"/>
        <source>Paper size</source>
        <translation>Taille du papier</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="564"/>
        <source>Print Layout</source>
        <translation>Mise en page de l&apos;impression</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="575"/>
        <source>Duplex</source>
        <translation>Duplex</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="588"/>
        <source>N-up printing</source>
        <translation>Impression N-up</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
        <source>2 pages/sheet, 1×2</source>
        <translation>2 pages/feuille, 1×2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
        <source>4 pages/sheet, 2×2</source>
        <translation>4 pages/feuille, 2×2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
        <source>6 pages/sheet, 2×3</source>
        <translation>6 pages/feuille, 2x3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
        <source>9 pages/sheet, 3×3</source>
        <translation>9 pages/feuille, 3x3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
        <source>16 pages/sheet, 4×4</source>
        <translation>16 pages/feuille, 4×4</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="599"/>
        <source>Layout direction</source>
        <translation>Direction de la mise en page</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="644"/>
        <source>Page Order</source>
        <translation>Ordre des pages</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="655"/>
        <source>Collate pages</source>
        <translation>Assembler les pages</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="661"/>
        <source>Print pages in order</source>
        <translation>Imprimer les pages dans l&apos;ordre</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="663"/>
        <source>Front to back</source>
        <translation>De l&apos;avant vers l&apos;arrière</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="663"/>
        <source>Back to front</source>
        <translation>De l&apos;arrière vers l&apos;avant</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="687"/>
        <source>Watermark</source>
        <translation>Filigrane</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="698"/>
        <source>Add watermark</source>
        <translation>Ajouter un filigrane</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="740"/>
        <source>Text watermark</source>
        <translation>Filigrane de texte</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
        <source>Confidential</source>
        <translation>Confidentiel</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
        <source>Draft</source>
        <translation>Brouillon</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
        <source>Sample</source>
        <translation>Échantillon</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
        <source>Custom</source>
        <translation>Personnaliser</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="750"/>
        <source>Input your text</source>
        <translation>Saisir votre texte</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="773"/>
        <source>Picture watermark</source>
        <translation>Filigrane d&apos;image</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="794"/>
        <source>Layout</source>
        <translation>Disposition</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="796"/>
        <source>Tile</source>
        <translation>Tuile</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="796"/>
        <source>Center</source>
        <translation>Centre</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="807"/>
        <source>Angle</source>
        <translation>Angle</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="823"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="844"/>
        <source>Transparency</source>
        <translation>Transparence</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="901"/>
        <source>Print to PDF</source>
        <translation>Imprimer au format PDF</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="902"/>
        <source>Save as Image</source>
        <translation>Enregistrer comme image</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1171"/>
        <source>Collapse</source>
        <translation>Réduire</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1294"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1301"/>
        <source>Flip on short edge</source>
        <translation>Retourner sur le bord court</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1297"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1300"/>
        <source>Flip on long edge</source>
        <translation>Retourner sur le bord long</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1397"/>
        <source>Input page numbers please</source>
        <translation>Veuillez saisir les numéros de page</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1400"/>
        <source>Maximum page number reached</source>
        <translation>Numéro de page maximum atteint</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1403"/>
        <source>Input English comma please</source>
        <translation>Veuillez entrer une virgule anglaise, s&apos;il vous plaît</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1406"/>
        <source>Input page numbers like this: 1,3,5-7,11-15,18,21</source>
        <translation>Entrer les numéros de page comme ceci : 1,3,5-7,11-15,18,21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1558"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2168"/>
        <source>*.pdf</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1672"/>
        <source>For example, 1,3,5-7,11-15,18,21</source>
        <translation>Par exemple, 1,3,5-7,11-15,18,21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2168"/>
        <source>Save as PDF</source>
        <translation>Enregistrer au format PDF</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2207"/>
        <source>Save as image</source>
        <translation>Enregistrer comme image</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2209"/>
        <source>Images</source>
        <translation>Images</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewWidget</name>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1590"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1593"/>
        <source>Confidential</source>
        <translation>Confidentiel</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1608"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1611"/>
        <source>Draft</source>
        <translation>Brouillon</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1626"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1629"/>
        <source>Sample</source>
        <translation>Échantillon</translation>
    </message>
</context>
<context>
    <name>DSearchEdit</name>
    <message>
        <location filename="../widgets/dsearchedit.cpp" line="291"/>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
</context>
<context>
    <name>DSettingsDialog</name>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="78"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="79"/>
        <source>Replace</source>
        <translation>Remplacer</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="81"/>
        <source>This shortcut conflicts with %1, click on Add to make this shortcut effective immediately</source>
        <translation>Ce raccourci est en conflit avec %1, cliquer sur Ajouter pour que ce raccourci soit effectif immédiatement.</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="31"/>
        <source>Please input a new shortcut</source>
        <translation>Veuillez entrer un nouveau raccourci</translation>
    </message>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="102"/>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
</context>
<context>
    <name>DTextEdit</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="171"/>
        <source>Stop reading</source>
        <translation>Arrêter la lecture</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="173"/>
        <source>Text to Speech</source>
        <translation>Texte vers voix</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="196"/>
        <source>Translate</source>
        <translation>Traduire</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="218"/>
        <source>Speech To Text</source>
        <translation>Voix vers texte</translation>
    </message>
</context>
<context>
    <name>PickColorWidget</name>
    <message>
        <location filename="../widgets/dprintpickcolorwidget.cpp" line="109"/>
        <source>Color</source>
        <translation>Couleur</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="454"/>
        <source>Select All</source>
        <translation>Tout sélectionner</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../widgets/dsimplelistview.cpp" line="1334"/>
        <source>No search result</source>
        <translation>Aucun résultat trouvé</translation>
    </message>
    <message>
        <location filename="../widgets/private/settings/content.cpp" line="331"/>
        <source>Restore Defaults</source>
        <translation>Réinitialiser par défaut</translation>
    </message>
</context>
<context>
    <name>QWidgetTextControl</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="163"/>
        <source>Select All</source>
        <translation>Tout sélectionner</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../widgets/private/settings/shortcutedit.cpp" line="117"/>
        <source>Please enter a new shortcut</source>
        <translation>Veuillez entrer un nouveau raccourci</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="527"/>
        <source>Theme</source>
        <translation>Thème</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="529"/>
        <source>Light Theme</source>
        <translation>Thème clair</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="530"/>
        <source>Dark Theme</source>
        <translation>Thème sombre</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="531"/>
        <source>System Theme</source>
        <translation>Thème du système</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="555"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="563"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="570"/>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
</context>
</TS>